@@ -32,7 +32,7 @@
 /* Comments for these variables are in gram.h.  */
 
 item_number *ritem = NULL;
-unsigned int nritems = 0;
+unsigned nritems = 0;
 
 rule *rules = NULL;
 rule_number nrules = 0;
@@ -46,6 +46,8 @@ symbol_number *token_translations = NULL;
 
 int max_user_token_number = 256;
 
+int required_version = 0;
+
 bool
 rule_useful_in_grammar_p (rule const *r)
 {
@@ -65,27 +67,26 @@ rule_useless_in_parser_p (rule const *r)
 }
 
 void
-rule_lhs_print (rule const *r, symbol const *previous_lhs, FILE *out)
+rule_lhs_print (rule const *r, sym_content const *previous_lhs, FILE *out)
 {
   fprintf (out, "  %3d ", r->number);
   if (previous_lhs != r->lhs)
-    fprintf (out, "%s:", r->lhs->tag);
+    fprintf (out, "%s:", r->lhs->symbol->tag);
   else
-    fprintf (out, "%*s|", (int) strlen (previous_lhs->tag), "");
+    fprintf (out, "%*s|", (int) strlen (previous_lhs->symbol->tag), "");
 }
 
 void
 rule_lhs_print_xml (rule const *r, FILE *out, int level)
 {
-  xml_printf (out, level, "<lhs>%s</lhs>", r->lhs->tag);
+  xml_printf (out, level, "<lhs>%s</lhs>", r->lhs->symbol->tag);
 }
 
 size_t
 rule_rhs_length (rule const *r)
 {
   size_t res = 0;
-  item_number *rhsp;
-  for (rhsp = r->rhs; *rhsp >= 0; ++rhsp)
+  for (item_number *rhsp = r->rhs; *rhsp >= 0; ++rhsp)
     ++res;
   return res;
 }
@@ -94,11 +95,8 @@ void
 rule_rhs_print (rule const *r, FILE *out)
 {
   if (0 <= *r->rhs)
-    {
-      item_number *rp;
-      for (rp = r->rhs; *rp >= 0; rp++)
-        fprintf (out, " %s", symbols[*rp]->tag);
-    }
+    for (item_number *rp = r->rhs; *rp >= 0; rp++)
+      fprintf (out, " %s", symbols[*rp]->tag);
   else
     fputs (" %empty", out);
 }
@@ -108,9 +106,8 @@ rule_rhs_print_xml (rule const *r, FILE *out, int level)
 {
   if (*r->rhs >= 0)
     {
-      item_number *rp;
       xml_puts (out, level, "<rhs>");
-      for (rp = r->rhs; *rp >= 0; rp++)
+      for (item_number *rp = r->rhs; *rp >= 0; rp++)
         xml_printf (out, level + 1, "<symbol>%s</symbol>",
                     xml_escape (symbols[*rp]->tag));
       xml_puts (out, level, "</rhs>");
@@ -126,9 +123,8 @@ rule_rhs_print_xml (rule const *r, FILE *out, int level)
 void
 ritem_print (FILE *out)
 {
-  unsigned int i;
   fputs ("RITEM\n", out);
-  for (i = 0; i < nritems; ++i)
+  for (unsigned i = 0; i < nritems; ++i)
     if (ritem[i] >= 0)
       fprintf (out, "  %s", symbols[ritem[i]]->tag);
     else
@@ -140,9 +136,7 @@ size_t
 ritem_longest_rhs (void)
 {
   int max = 0;
-  rule_number r;
-
-  for (r = 0; r < nrules; ++r)
+  for (rule_number r = 0; r < nrules; ++r)
     {
       int length = rule_rhs_length (&rules[r]);
       if (length > max)
@@ -156,12 +150,11 @@ void
 grammar_rules_partial_print (FILE *out, const char *title,
                              rule_filter filter)
 {
-  rule_number r;
   bool first = true;
-  symbol *previous_lhs = NULL;
+  sym_content *previous_lhs = NULL;
 
   /* rule # : LHS -> RHS */
-  for (r = 0; r < nrules + nuseless_productions; r++)
+  for (rule_number r = 0; r < nrules + nuseless_productions; r++)
     {
       if (filter && !filter (&rules[r]))
         continue;
@@ -188,10 +181,9 @@ grammar_rules_print (FILE *out)
 void
 grammar_rules_print_xml (FILE *out, int level)
 {
-  rule_number r;
   bool first = true;
 
-  for (r = 0; r < nrules + nuseless_productions; r++)
+  for (rule_number r = 0; r < nrules + nuseless_productions; r++)
     {
       if (first)
         xml_puts (out, level + 1, "<rules>");
@@ -209,7 +201,7 @@ grammar_rules_print_xml (FILE *out, int level)
                  rules[r].number, usefulness);
         if (rules[r].precsym)
           fprintf (out, " percent_prec=\"%s\"",
-                   xml_escape (rules[r].precsym->tag));
+                   xml_escape (rules[r].precsym->symbol->tag));
         fputs (">\n", out);
       }
       rule_lhs_print_xml (&rules[r], out, level + 3);
@@ -233,31 +225,28 @@ grammar_dump (FILE *out, const char *title)
 
   fprintf (out, "Variables\n---------\n\n");
   {
-    symbol_number i;
     fprintf (out, "Value  Sprec  Sassoc  Tag\n");
 
-    for (i = ntokens; i < nsyms; i++)
+    for (symbol_number i = ntokens; i < nsyms; i++)
       fprintf (out, "%5d  %5d   %5d  %s\n",
                i,
-               symbols[i]->prec, symbols[i]->assoc,
+               symbols[i]->content->prec, symbols[i]->content->assoc,
                symbols[i]->tag);
     fprintf (out, "\n\n");
   }
 
   fprintf (out, "Rules\n-----\n\n");
   {
-    rule_number i;
     fprintf (out,
              "Num (Prec, Assoc, Useful, Ritem Range) Lhs"
              " -> Rhs (Ritem range) [Num]\n");
-    for (i = 0; i < nrules + nuseless_productions; i++)
+    for (rule_number i = 0; i < nrules + nuseless_productions; i++)
       {
         rule const *rule_i = &rules[i];
-        item_number *rp = NULL;
-        unsigned int rhs_itemno = rule_i->rhs - ritem;
-        unsigned int rhs_count = 0;
+        unsigned const rhs_itemno = rule_i->rhs - ritem;
         /* Find the last RHS index in ritems. */
-        for (rp = rule_i->rhs; *rp >= 0; ++rp)
+        unsigned rhs_count = 0;
+        for (item_number *rp = rule_i->rhs; *rp >= 0; ++rp)
           ++rhs_count;
         fprintf (out, "%3d (%2d, %2d, %2d, %2u-%2u)   %2d ->",
                  i,
@@ -268,32 +257,32 @@ grammar_dump (FILE *out, const char *title)
                  rhs_itemno + rhs_count - 1,
                  rule_i->lhs->number);
         /* Dumped the RHS. */
-        for (rp = rule_i->rhs; *rp >= 0; rp++)
+        for (item_number *rp = rule_i->rhs; *rp >= 0; ++rp)
           fprintf (out, " %3d", *rp);
-        fprintf (out, "  [%d]\n", item_number_as_rule_number (*rp));
+        fprintf (out, "  [%d]\n",
+                 item_number_as_rule_number (rule_i->rhs[rhs_count+1]));
       }
   }
   fprintf (out, "\n\n");
 
   fprintf (out, "Rules interpreted\n-----------------\n\n");
-  {
-    rule_number r;
-    for (r = 0; r < nrules + nuseless_productions; r++)
-      {
-        fprintf (out, "%-5d  %s:", r, rules[r].lhs->tag);
-        rule_rhs_print (&rules[r], out);
-        fprintf (out, "\n");
-      }
-  }
+  for (rule_number r = 0; r < nrules + nuseless_productions; r++)
+    {
+      fprintf (out, "%-5d  %s:", r, rules[r].lhs->symbol->tag);
+      rule_rhs_print (&rules[r], out);
+      fprintf (out, "\n");
+    }
   fprintf (out, "\n\n");
 }
 
 void
 grammar_rules_useless_report (const char *message)
 {
-  rule_number r;
-  for (r = 0; r < nrules ; ++r)
-    if (!rules[r].useful)
+  for (rule_number r = 0; r < nrules ; ++r)
+    /* Don't complain about rules whose LHS is useless, we already
+       complained about it.  */
+    if (!reduce_nonterminal_useless_in_grammar (rules[r].lhs)
+        && !rules[r].useful)
       complain (&rules[r].location, Wother, "%s", message);
 }
 
